pub enum ZSeekFrom {
Start(u64),
End(i64),
Current(i64),
}Expand description
Enumeration of possible methods to seek within an I/O object.
It is analogous to the SeekFrom in the std library but it’s here to allow this to work in no-std crates
Variants
Start(u64)
Sets the offset to the provided number of bytes.
End(i64)
Sets the offset to the size of this object plus the specified number of bytes.
It is possible to seek beyond the end of an object, but it’s an error to seek before byte 0.
Current(i64)
Sets the offset to the current position plus the specified number of bytes.
It is possible to seek beyond the end of an object, but it’s an error to seek before byte 0.
Implementations